#!/usr/bin/env python
# $Id$

import sys
import getopt
from math import sqrt

OPTIONS = ("hW:H:a:b:c:p",["help","Width=","Height=","aspect=","bitrate=","cq=", "pal"])

def calculate_ARc(Wc, Hc, ARa, PRdvd):
    return (Wc * (ARa/PRdvd))/Hc

def calculate_ResY(bitrate, ARc, CQ):
    resy = int(sqrt(1000.0*float(bitrate)/25.0/float(ARc)/float(CQ))/16.0) * 16
    return resy

def calculate_ResX(ResY, ARc):
    resx = int(float(ResY)*float(ARc)/16.0)*16
    return resx

def usage():
    for each in OPTIONS[1]:
        print "-" + each[0] + ", --" + each

def main():
    Wc = 0.0
    Hc = 0.0
    ARa = 16.0 / 9.0
    bitrate = 0.0
    PRdvd = 1.5
    CQ = 0.16
    if sys.argv[1:] == []:
        usage()
        sys.exit(2)
    try:
        opts,args = getopt.getopt(sys.argv[1:], OPTIONS[0], OPTIONS[1])
    except getopt.GetoptError:
        # print help information and exit:
        usage()
        sys.exit(2)
    for o,a in opts:
        if o in ("-h","--help"):
            usage()
            sys.exit(2)
        if o in ("-W","--Width"):
            Wc = float(a)
        if o in ("-H","--Height"):
            Hc = float(a)
        if o in ("-a", "--aspect"):
            if a not in ("4/3","16/9"):
                usage()
                sys.exit(2)
            if a == "4/3":
                ARa = 4.0 / 3.0
            else:
                ARa = 16.0 / 9.0
        if o in ("-b", "--bitrate"):
            bitrate = float(a)
        if o in ("-c", "--cq"):
            CQ = float(a)
        if o in ("-p", "--pal"):
            PRdvd = 1.25

    ARc=calculate_ARc(Wc, Hc, ARa, PRdvd)
    ResY=calculate_ResY(bitrate, ARc, CQ) 
    ResX=calculate_ResX(ResY, ARc)

    print ResX,"x",ResY

if __name__ == "__main__":
    main()

#Wc=704.0
#Hc=464.0
#bitrate=1397.0
#ARa=1.333
#PRdvd=1.5
#CQ=0.16

# vim:syntax=python
# vim:sw=4:softtabstop=4:expandtab
